@@ -31,17 +31,20 @@ def comp_fft_freqs(time, is_time, is_positive):
     Frequency/wavenumber vector
     """
     N_tot = time.size  # Number of samples
+    if N_tot==1:
+        freqs = [0]
+    else:
     # zero-padding
     # N_tot = int(2**(log(N_tot)//log(2)+1))
-    timestep = float(time[1] - time[0])  # Sample step
-    fsampt = 1.0 / timestep  # Sample frequency
-    freqscale = N_tot / fsampt
-    if is_positive:
-        freqs = [i for i in range(int(N_tot / 2) + 1)]
-    else:
-        freqs = [i - int(N_tot / 2) for i in range(int(N_tot))]
-    if is_time:
-        freqs = [i / freqscale for i in freqs]
+        timestep = float(time[1] - time[0])  # Sample step
+        fsampt = 1.0 / timestep  # Sample frequency
+        freqscale = N_tot / fsampt
+        if is_positive:
+            freqs = [i for i in range(int(N_tot / 2) + 1)]
+        else:
+            freqs = [i - int(N_tot / 2) for i in range(int(N_tot))]
+        if is_time:
+            freqs = [i / freqscale for i in freqs]
     return freqs
 
 
@@ -57,12 +60,15 @@ def comp_fft_time(freqs, is_angle):
     -------
     Time/space vector
     """
-    N_tot = len(freqs)  # Number of samples
-    fsampt = freqs[-1] * 2.0
-    timestep = 1.0 / fsampt
-    if is_angle:
-        timestep *= 2.0 * pi
-    time = [0 + i * timestep for i in range(N_tot)]
+    if freqs.size==1:
+        time = [0]
+    else:
+        N_tot = len(freqs)  # Number of samples
+        fsampt = freqs[-1] * 2.0
+        timestep = 1.0 / fsampt
+        if is_angle:
+            timestep *= 2.0 * pi
+        time = [0 + i * timestep for i in range(N_tot)]
     return time
 
 
